# Oauth2Auth

Configuration for OAuth2 authentication.  Systems using this will exchange credentials with the configured token endpoint, providing them with an access token. It will use this access token to perform bearer authentication. The credential exchange will either use a hardcoded password (client_secret) or perform oidc federation (federated_audience), or use a jwt-based client_assertion derived from a private key provisioned elsewhere (e.g. in the secrets of a Credential). 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token_url** | **str** | The url from which to fetch access tokens.  | 
**client_id** | **str** | The client id to present to the token endpoint  | 
**client_secret** | **str** | The secret to present when doing credential authentication  | [optional] 
**scopes** | **[str]** | The scopes to ask for  | [optional] 
**federated_audience** | **str** | The audience to provide when performing OIDC federation.  | [optional] 
**bearer_fingerprint** | **str** | The fingerprint of the certificate used to authenticate the bearer token used for the client_assertion in a client-credentials flow. Typically base-64 url encoded. Typically sha256, but can use other hashes if supported. This is used by the OAuth2 authorization server in its token authentication. In particular, the x5t header will be provisioned with this value.  This is typically used in conjunction with a private key to create a jwt assertion.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


